==> piwigo-2.5.1.zip: piwigo/language/af_ZA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Admin configuration'] = 'Admin konfigurasie';
$lang['Basic configuration'] = 'Basiese konfigurasie';
$lang['Congratulations, Piwigo installation is completed'] = 'Baie geluk, Piwigo installasie is voltooi';
$lang['Database configuration'] = 'Databasis konfigurasie';
$lang['Download the config file'] = 'Laai die konfigurasie lêer af';
$lang['Installation'] = 'Installasie';
$lang['Just another Piwigo gallery'] = 'Net nog \'n Piwigo gallery';
$lang['Password [confirm]'] = 'Wagwoord [bevestig]';
$lang['PHP 5 is required'] = 'PHP 5 word vereis';
$lang['Sorry!'] = 'Jammer!';
$lang['Start Install'] = 'Begin installasie';
$lang['User'] = 'Gebruiker';
$lang['verification'] = 'verifikasie';
$lang['Webmaster login'] = 'Webmeester login';
$lang['Webmaster mail address'] = 'Webmeester epos adres';
$lang['Welcome to my photo gallery'] = 'Welkom by my fotogallery';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jy kan die konfigurasie lêer aflaai en oplaai na die local/config gids van jou installasie';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatiewelik kan die teks in die boksie hier bo gekopiëer word en in die lêer "local/config/database.inc.php" gestoor word. Maak seker die lêer bevat slegs die teks hier bo en geen nuwe-lyn karakters of spasies nie.';
$lang['Can\'t connect to server'] = 'Kan nie aan die bediener verbind nie';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Verbinding aan bediener was suksesvol, maar daar kon nie aan die databasis verbind word nie';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Fout tydens die skepping van opstellings-lêer local/config/database.inc.php ';
$lang['Database name'] = 'Databasisnaam';
$lang['Database table prefix'] = 'Databasis tabelnaam-voorvoegsel';
$lang['Default gallery language'] = 'Gallery se standaard taal';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Moet nie skroom om ons forum om hulp te besoek nie: %s';
$lang['Hope to see you back soon.'] = 'Tot later.';
$lang['Host'] = 'Gasheer (naam van bediener)';
$lang['It appears your webhost is currently running PHP %s.'] = 'Dit wil voorkom of jou bediener PHP weergawe %s gebruik.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Dit sal vir besoekers getoon word en is noodsaaklik vir webtuiste-administrasie';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hou dit geheim. Dit laat jou toe om administrasieblasye te sien';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Benodig hulp? Vra jou vraag op die <a href="%s">Piwigo aanplakbord</a>';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Let op dat jy self die opstelling kan verander en daarna Piwigo heruitvoer.';
$lang['Password'] = 'Wagwoord';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan probeer om PHP 5 te gebruik deur \'n .htaccess-lêer te skep of te verander.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kon nie PHP 5 opstel nie.';
$lang['Try to configure PHP 5'] = 'Probeer PHP 5 op te stel';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besoekers sal hierdie adres kan gebruik om die webmeester te kontak';
$lang['Webmaster password'] = 'Webmeester wagwoord';
$lang['Welcome to your new installation of Piwigo!'] = 'Welkom by jou nuwe Piwigo webtuiste!';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Verwys na jou diensverskaffer om uit te vind hoe jy PHP 5 kan gebruik.';
$lang['also given by your host provider'] = 'ook deur diensverskaffer voorsien';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'dit sal vooraan tabelname geheg word om tabelle beter te bestuur';
$lang['enter a login for webmaster'] = 'kies \'n gebruikersnaam vir die webmeester';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-pos-adresse moet in die vorm aaa@bbb.ccc wees (voorbeeld: jack@altern.org)';
$lang['please enter your password again'] = 'tike assblief weer jou wagwoord in';
$lang['user login given by your host provider'] = 'gebruikersnaam deur diensverskaffer voorsien';
$lang['user password given by your host provider'] = 'wagwoord deur diensverskaffer voorsien';
$lang['webmaster login can\'t contain characters \' or "'] = 'gebruikersnaam kan nie die karakter \' en " bevat nie';
?>

==> piwigo-2.7.4.zip: piwigo/language/af_ZA/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Admin configuration'] = 'Admin konfigurasie';
$lang['Basic configuration'] = 'Basiese konfigurasie';
$lang['Congratulations, Piwigo installation is completed'] = 'Baie geluk, Piwigo installasie is voltooi';
$lang['Database configuration'] = 'Databasis konfigurasie';
$lang['Download the config file'] = 'Laai die konfigurasie lêer af';
$lang['Installation'] = 'Installasie';
$lang['Just another Piwigo gallery'] = 'Net nog \'n Piwigo gallery';
$lang['Password [confirm]'] = 'Wagwoord [bevestig]';
$lang['PHP 5 is required'] = 'PHP 5 word vereis';
$lang['Sorry!'] = 'Jammer!';
$lang['Start Install'] = 'Begin installasie';
$lang['User'] = 'Gebruiker';
$lang['verification'] = 'verifikasie';
$lang['Welcome to my photo gallery'] = 'Welkom by my fotogallery';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Jy kan die konfigurasie lêer aflaai en oplaai na die local/config gids van jou installasie';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternatiewelik kan die teks in die boksie hier bo gekopiëer word en in die lêer "local/config/database.inc.php" gestoor word. Maak seker die lêer bevat slegs die teks hier bo en geen nuwe-lyn karakters of spasies nie.';
$lang['Can\'t connect to server'] = 'Kan nie aan die bediener verbind nie';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Verbinding aan bediener was suksesvol, maar daar kon nie aan die databasis verbind word nie';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Fout tydens die skepping van opstellings-lêer local/config/database.inc.php ';
$lang['Database name'] = 'Databasisnaam';
$lang['Database table prefix'] = 'Databasis tabelnaam-voorvoegsel';
$lang['Default gallery language'] = 'Gallery se standaard taal';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Moet nie skroom om ons forum om hulp te besoek nie: %s';
$lang['Hope to see you back soon.'] = 'Tot later.';
$lang['Host'] = 'Gasheer (naam van bediener)';
$lang['It appears your webhost is currently running PHP %s.'] = 'Dit wil voorkom of jou bediener PHP weergawe %s gebruik.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Dit sal vir besoekers getoon word en is noodsaaklik vir webtuiste-administrasie';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hou dit geheim. Dit laat jou toe om administrasieblasye te sien';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Benodig hulp? Vra jou vraag op die <a href="%s">Piwigo aanplakbord</a>';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Let op dat jy self die opstelling kan verander en daarna Piwigo heruitvoer.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan probeer om PHP 5 te gebruik deur \'n .htaccess-lêer te skep of te verander.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo kon nie PHP 5 opstel nie.';
$lang['Try to configure PHP 5'] = 'Probeer PHP 5 op te stel';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besoekers sal hierdie adres kan gebruik om die webmeester te kontak';
$lang['Welcome to your new installation of Piwigo!'] = 'Welkom by jou nuwe Piwigo webtuiste!';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Verwys na jou diensverskaffer om uit te vind hoe jy PHP 5 kan gebruik.';
$lang['also given by your host provider'] = 'ook deur diensverskaffer voorsien';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'dit sal vooraan tabelname geheg word om tabelle beter te bestuur';
$lang['enter a login for webmaster'] = 'kies \'n gebruikersnaam vir die webmeester';
$lang['please enter your password again'] = 'tike assblief weer jou wagwoord in';
$lang['user login given by your host provider'] = 'gebruikersnaam deur diensverskaffer voorsien';
$lang['user password given by your host provider'] = 'wagwoord deur diensverskaffer voorsien';
$lang['webmaster login can\'t contain characters \' or "'] = 'gebruikersnaam kan nie die karakter \' en " bevat nie';
$lang['localhost or other, supplied by your host provider'] = 'localhost of ander, voorsien deur jou diensverskaffer';
?>
